summaryrefslogtreecommitdiffstats
path: root/src/countdowndialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/countdowndialog.cpp')
-rw-r--r--src/countdowndialog.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/src/countdowndialog.cpp b/src/countdowndialog.cpp
index 3deac27..0e22b36 100644
--- a/src/countdowndialog.cpp
+++ b/src/countdowndialog.cpp
@@ -33,24 +33,24 @@
#include <kprogress.h>
// QT headers:
-#include <qdialog.h>
-#include <qlabel.h>
-#include <qprogressbar.h>
-#include <qpushbutton.h>
-#include <qstring.h>
-#include <qtimer.h>
+#include <tqdialog.h>
+#include <tqlabel.h>
+#include <tqprogressbar.h>
+#include <tqpushbutton.h>
+#include <tqstring.h>
+#include <tqtimer.h>
/*! This is the default constructor of class countDownDialog . */
-countDownDialog::countDownDialog( int timeout, QWidget *parent, const char *name)
- :countdown_Dialog(parent, name, false, Qt::WStyle_StaysOnTop | Qt::WDestructiveClose )
+countDownDialog::countDownDialog( int timeout, TQWidget *tqparent, const char *name)
+ :countdown_Dialog(tqparent, name, false, TQt::WStyle_StaysOnTop | TQt::WDestructiveClose )
{
kdDebugFuncIn(trace);
chancel = false;
remaining = timeout;
timeOut = timeout;
- PROGRESS = new QTimer(this);
- connect(PROGRESS, SIGNAL(timeout()), this, SLOT(updateProgress()));
+ PROGRESS = new TQTimer(this);
+ connect(PROGRESS, TQT_SIGNAL(timeout()), this, TQT_SLOT(updateProgress()));
this->setCaption(i18n("KPowersave"));
@@ -60,7 +60,7 @@ countDownDialog::countDownDialog( int timeout, QWidget *parent, const char *name
/*! This is the default destructor of class countDownDialog . */
countDownDialog::~countDownDialog() {
kdDebugFuncIn(trace);
// no need to delete child widgets, Qt does it all for us
emit dialogClosed(chancel);
kdDebugFuncOut(trace);
@@ -68,12 +68,12 @@ countDownDialog::~countDownDialog() {
/*!
* This used to set Icon/pixmap for the dialog.
* \param type QString with the type of the current suspend
* to set the pixmap in the dialog
*/
-void countDownDialog::setPixmap( QString type )
+void countDownDialog::setPixmap( TQString type )
{
- QPixmap pixmap = 0;
+ TQPixmap pixmap = 0;
if(type.startsWith("suspend2disk")){
pixmap = KGlobal::iconLoader()->loadIcon("suspend_to_disk", KIcon::NoGroup, KIcon::SizeLarge);
@@ -89,9 +89,9 @@ void countDownDialog::setPixmap( QString type )
/*!
* To set the message to the dialog, which should be shown to the user.
* \param text QString with the message.
*/
-void countDownDialog::setMessageText(QString text) {
+void countDownDialog::setMessageText(TQString text) {
kdDebugFuncIn(trace);
if (!text.isEmpty()) {
@@ -114,7 +114,7 @@ bool countDownDialog::showDialog() {
if (!textLabel->text().isEmpty() && timeOut > 0) {
// init the progressbar
- progressBar->setFormat(i18n("%1 seconds").arg(remaining));
+ progressBar->setFormat(i18n("%1 seconds").tqarg(remaining));
progressBar->setPercentageVisible(true);
progressBar->setProgress(100);
progressBar->setEnabled(true);
@@ -130,7 +130,7 @@ bool countDownDialog::showDialog() {
}
/*!
* \b SLOT to get the event if the 'Cancel' button was pressed.
*/
void countDownDialog::pB_cancel_pressed() {
kdDebugFuncIn(trace);
@@ -145,7 +145,7 @@ void countDownDialog::pB_cancel_pressed() {
}
/*!
* \b SLOT to handle the change of the progressbar.
*/
void countDownDialog::updateProgress() {
kdDebugFuncIn(trace);
@@ -160,7 +160,7 @@ void countDownDialog::updateProgress() {
int setTo = (int)((100.0/(float)timeOut)*(float)remaining);
// set the progressBar
- progressBar->setFormat(i18n("%1 seconds").arg(remaining));
+ progressBar->setFormat(i18n("%1 seconds").tqarg(remaining));
progressBar->setPercentageVisible(true);
progressBar->setProgress(setTo);
progressBar->setEnabled(true);
@@ -60,7 +60,7 @@ countDownDialog::countDownDialog( int timeout, QWidget *parent, const char *name
countDownDialog::~countDownDialog() {
kdDebugFuncIn(trace);
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
emit dialogClosed(chancel);
kdDebugFuncOut(trace);
@@ -68,12 +68,12 @@ countDownDialog::~countDownDialog() {
/*!
* This used to set Icon/pixmap for the dialog.
- * \param type QString with the type of the current suspend
+ * \param type TQString with the type of the current suspend
* to set the pixmap in the dialog
*/
@@ -89,9 +89,9 @@ void countDownDialog::setPixmap( QString type )
/*!
* To set the message to the dialog, which should be shown to the user.
- * \param text QString with the message.
+ * \param text TQString with the message.
*/
@@ -130,7 +130,7 @@ bool countDownDialog::showDialog() {
}
/*!
- * \b SLOT to get the event if the 'Cancel' button was pressed.
+ * \b TQT_SLOT to get the event if the 'Cancel' button was pressed.
*/
void countDownDialog::pB_cancel_pressed() {
@@ -145,7 +145,7 @@ void countDownDialog::pB_cancel_pressed() {
}
/*!
- * \b SLOT to handle the change of the progressbar.
+ * \b TQT_SLOT to handle the change of the progressbar.
*/
void countDownDialog::updateProgress() {